#
# spec file for package audacious
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# The information is available in src/audacious/plugin.h (_AUD_PLUGIN_VERSION_MIN and _AUD_PLUGIN_VERSION).
# If you know how to automatically get the information from there (at this point is still not uncompressed), please change this.
%define aud_plugin_api_min 40
%define aud_plugin_api_max 43

%define client_soname 2
%define core_soname 1
%define gui_soname 1
%define tag_soname 1

Name:           audacious
Version:        3.4.2
Release:        1.2
Summary:        Advanced audio player
License:        BSD-2-Clause
Group:          Productivity/Multimedia/Sound/Players
Url:            http://audacious-media-player.org/
Source0:        http://distfiles.audacious-media-player.org/audacious-%{version}.tar.bz2
BuildRequires:  desktop-file-utils
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig(cairo) >= 1.6
BuildRequires:  pkgconfig(dbus-1) >= 0.60
BuildRequires:  pkgconfig(dbus-glib-1) >= 0.60
BuildRequires:  pkgconfig(glib-2.0) >= 2.16
BuildRequires:  pkgconfig(gmodule-2.0) >= 2.16
BuildRequires:  pkgconfig(gthread-2.0) >= 2.16
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.0.0
BuildRequires:  pkgconfig(libguess) >= 1.1
BuildRequires:  pkgconfig(pango) >= 1.20
Requires:       audacious-plugin(Output)%{?_isa} >= %{aud_plugin_api_min}
Requires:       audacious-plugin(Output)%{?_isa} <= %{aud_plugin_api_max}
Requires:       audacious-plugin(Interface)%{?_isa} >= %{aud_plugin_api_min}
Requires:       audacious-plugin(Interface)%{?_isa} <= %{aud_plugin_api_max}
Requires:       audacious-plugin(Input)%{?_isa} >= %{aud_plugin_api_min}
Requires:       audacious-plugin(Input)%{?_isa} <= %{aud_plugin_api_max}

%description
Audacious is an advanced audio player. It is free, lightweight, currently
based on GTK+ 3, runs on Linux and many other *nix platforms and is
focused on audio quality and supporting a wide range of audio codecs.
It still features an alternative skinned user interface (based on
Winamp 2.x skins). Historically, it started as a fork of Beep Media
Player (BMP), which itself forked from XMMS.

%package -n libaudclient%{client_soname}
Summary:        Library to control the Audacious media player
Group:          System/Libraries

%description -n libaudclient%{client_soname}
Library from the Audacious media player.

%package -n libaudcore%{core_soname}
Summary:        Library from the Audacious media player
Group:          System/Libraries
# All the values from min to max
Provides:       audacious(plugin-api)%{?_isa} = %{aud_plugin_api_min}
Provides:       audacious(plugin-api)%{?_isa} = 41
Provides:       audacious(plugin-api)%{?_isa} = 42
Provides:       audacious(plugin-api)%{?_isa} = %{aud_plugin_api_max}

%description -n libaudcore%{core_soname}
Library from the Audacious media player.

%package -n libaudgui%{gui_soname}
Summary:        Library from the Audacious media player
Group:          System/Libraries
Requires:       libaudcore%{core_soname} >= %{version}

%description -n libaudgui%{gui_soname}
Library from the Audacious media player.

%package -n libaudtag%{tag_soname}
Summary:        Library from the Audacious media player
Group:          System/Libraries
Requires:       libaudcore%{core_soname} >= %{version}

%description -n libaudtag%{tag_soname}
Library from the Audacious media player.

%package devel
Summary:        Development files for audacious
Group:          Development/Libraries/C and C++
Requires:       libaudcore%{core_soname} = %{version}
Requires:       libaudgui%{gui_soname} = %{version}
Requires:       libaudtag%{tag_soname} = %{version}

%description devel
Development files for audacious.

%package -n libaudclient-devel
Summary:        Development files for libaudclient
Group:          Development/Libraries/C and C++
Requires:       libaudclient%{client_soname} = %{version}

%description -n libaudclient-devel
Development files for libaudclient.

%prep
%setup -q
# Make build verbose
sed -i '\,^.SILENT:,d' buildsys.mk.in

%build
%configure --disable-rpath
make %{?_smp_mflags}

%install
%make_install
%find_lang %{name}

%post
%icon_theme_cache_post
%desktop_database_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%post -n libaudclient%{client_soname} -p /sbin/ldconfig

%postun -n libaudclient%{client_soname} -p /sbin/ldconfig

%post -n libaudcore%{core_soname} -p /sbin/ldconfig

%postun -n libaudcore%{core_soname} -p /sbin/ldconfig

%post -n libaudgui%{gui_soname} -p /sbin/ldconfig

%postun -n libaudgui%{gui_soname} -p /sbin/ldconfig

%post -n libaudtag%{tag_soname} -p /sbin/ldconfig

%postun -n libaudtag%{tag_soname} -p /sbin/ldconfig

%files -f %{name}.lang
%defattr(0644,root,root,0755)
%attr(0755,root,root) %{_bindir}/audacious
%{_mandir}/man1/audacious.1*
%attr(0755,root,root) %{_bindir}/audtool
%{_mandir}/man1/audtool.1*
%{_datadir}/audacious/
%{_datadir}/applications/audacious.desktop
%{_datadir}/icons/hicolor/*/apps/audacious.*

%files -n libaudclient%{client_soname}
%defattr(0644,root,root,0755)
%doc AUTHORS COPYING
%{_libdir}/libaudclient.so.%{client_soname}*

%files -n libaudcore%{core_soname}
%defattr(0644,root,root,0755)
%doc AUTHORS COPYING
%{_libdir}/libaudcore.so.%{core_soname}*

%files -n libaudgui%{gui_soname}
%defattr(0644,root,root,0755)
%{_libdir}/libaudgui.so.%{gui_soname}*

%files -n libaudtag%{tag_soname}
%defattr(0644,root,root,0755)
%{_libdir}/libaudtag.so.%{tag_soname}*

%files devel
%defattr(0644,root,root,0755)
%{_libdir}/libaudcore.so
%{_libdir}/libaudgui.so
%{_libdir}/libaudtag.so
%{_includedir}/audacious/
%exclude %{_includedir}/audacious/audctrl.h
%{_includedir}/libaudcore/
%{_includedir}/libaudgui/
%{_libdir}/pkgconfig/audacious.pc

%files -n libaudclient-devel
%defattr(0644,root,root,0755)
%{_libdir}/libaudclient.so
%dir %{_includedir}/audacious/
%{_includedir}/audacious/audctrl.h
%{_libdir}/pkgconfig/audclient.pc

%changelog
* Tue Dec 17 2013 reddwarf@opensuse.org
- Update to 3.4.2
* Fri Mar 29 2013 fisiu@opensuse.org
- Update to 3.3.4:
  * Ported from gtk2 to gtk3
  * Save current track position
  * Improved search feature
  * Many bug fixes
* Sun Aug 19 2012 seife+obs@b1-systems.com
- update to current version 3.2.4
- removed no longer necessary -lgmodule-2.0 hack
* Tue May 22 2012 seife+obs@b1-systems.com
- fix build on > 12.1 by adding -lgmodule-2.0 to LIBS
* Fri Dec  9 2011 detlef@links2linux.de
- new upstream version <3.1.1>
* Sun Nov 20 2011 pascal.bleser@opensuse.org
- update to 3.1
* Sun Nov  6 2011 detlef@links2linux.de
- new upstream version <3.0.3>
* Sun Aug 28 2011 detlef@links2linux.de
- new upstream version <3.0.2>
* Sat Aug 13 2011 detlef@links2linux.de
- new upstream version <3.0.1>
* Sat Jul  2 2011 detlef@links2linux.de
- new upstream version <2.5.3>
* Thu Jun 23 2011 detlef@links2linux.de
- new upstream version <2.5.2>
* Sat May 21 2011 detlef@links2linux.de
- new upstream version <2.5.1>
* Sun Apr 17 2011 detlef@links2linux.de
- new upstream version <2.5.0>
* Wed Feb 23 2011 detlef@links2linux.de
- new upstream version <2.4.4>
* Fri Jan 14 2011 detlef@links2linux.de
- new upstream version <2.4.3>
* Wed Dec  8 2010 detlef@links2linux.de
- new upstream version <2.4.2>
* Fri Aug 27 2010 detlef@links2linux.de
- enable libguess support
* Wed Aug 25 2010 detlef@links2linux.de
- new upstream version <2.4-rc3>
* Fri Apr  9 2010 detlef@links2linux.de
- new upstream version <2.3>
* Wed Nov 25 2009 detlef@links2linux.de
- new upstream version <2.2>
* Wed Jul  8 2009 Manfred.Tremmel@iiv.de
- new upstream version <2.1>
* Fri Jun  5 2009 Manfred.Tremmel@iiv.de
- new upstream version <2.0.1>
* Tue Jul 22 2008 guru@unixtech.be
- added InitialPreference to action_audacious.desktop as it is associated
  with directories, in order to avoid it being the default action on
  directories
- added patch to fix specifying files on the command-line when audacious
  isn't already running: http://bugzilla.atheme.org/show_bug.cgi?id=48
* Sun Jul 20 2008 detlef@links2linux.de
- require audacious-plugins instead of audacious-plugins-option
  package managers are stupid ;)
* Thu Jul 10 2008 guru@unixtech.be
- require audacious-plugins-option instead of audacious-plugins
* Sun Jul  6 2008 guru@unixtech.be
- split shared libraries into its own -libs subpackage to avoid the chicken/egg
  problem when building audacious and audacious-plugins (as they both require
  each other), with audacious now requiring audacious-libs
- minor spec file cleanups
- added Provides for shlibs, openSUSE Shared Library Policy compliant
- more explicit filenames in files sections
- better Summary
- added glib backport patch to build on openSUSE 10.2
* Mon May 26 2008 detlef@links2linux.de
- new upstream version <1.5.1>
* Tue Apr 22 2008 detlef@links2linux.de
- fix Requires for devel
* Sun Mar 30 2008 detlef@links2linux.de
- disable ss2 for ix86, some old cpus doesn't support sse2
* Sat Mar 15 2008 detlef@links2linux.de
- new upstream version <1.5.0>
* Mon Feb 18 2008 detlef@links2linux.de
- rebuild with new libmcs-0.7
* Fri Feb  1 2008 detlef@links2linux.de
- new upstream version <1.4.6>
* Sat Dec 29 2007 detlef@links2linux.de
- new upstream version <1.4.5>
* Sat Dec 22 2007 detlef@links2linux.de
- rebuild for new libmcs and libmowgli
* Sat Dec  8 2007 detlef@links2linux.de
- add servicemenu for konqueror and dolphin
* Mon Dec  3 2007 detlef@links2linux.de
- new upstream version <1.4.4>
* Sat Dec  1 2007 detlef@links2linux.de
- new upstream version <1.4.3>
* Mon Nov 19 2007 detlef@links2linux.de
- new upstream release <1.4.1>
* Tue Nov  6 2007 detlef@links2linux.de
- new upstream release <1.4.0>
* Mon Nov  5 2007 detlef@links2linux.de
- switch to 1.4 on PackMan
- Audacious 1.4 is now complete, and is now recommended over 1.3
* Fri Nov  2 2007 detlef@links2linux.de
- new upstream release <1.4.0-rc1>
* Mon Oct 29 2007 detlef@links2linux.de
- new upstream release <1.4.0-beta4>
* Fri Oct 19 2007 detlef@links2linux.de
- new upstream release <1.4.0-beta2>
* Mon Oct 15 2007 detlef@links2linux.de
- new upstream release <1.4.0-beta1>
* Thu Sep 20 2007 detlef@links2linux.de
- add xchat-plugin
* Thu Sep 13 2007 detlef@links2linux.de
- new upstream release <1.4.0-dr4>
* Sun Sep  9 2007 detlef@links2linux.de
- new upstream release <1.4.0-dr3>
* Thu Aug  9 2007 detlef@links2linux.de
- new upstream release <1.4.0-dr2>
- fix BuildRequires -> add dbus-support
* Mon Jul 23 2007 detlef@links2linux.de
- initial build <1.4.0-dr1>
